/*
 *  Copyright (C) 2006 DFKI GmbH
 *  Image Understanding and Pattern Recognition Lab
 *  Author: Christian Kofler <christian.kofler@dfki.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <iostream>

using namespace std;

#include "FireClient.h"


BEGIN_EVENT_TABLE(FireClient, wxEvtHandler)
    EVT_SOCKET(SOCKET_ID, FireClient::OnSocketEvent)
END_EVENT_TABLE()


FireClient::FireClient() {
    socket = 0;
    connected = false;
    socketInputStream = 0;
    textInputStream = 0;
    input = wxT("");
}

FireClient::~FireClient() {
    if (socket != 0) socket->Destroy();
}

bool FireClient::connect(wxString host, unsigned short port) {

    if (host.IsEmpty() || port == 0) return false;

    wxIPV4address addr;
    addr.Hostname(host);
    addr.Service(port);

    // Create the socket
    socket = new wxSocketClient();

    // Set up the event handler and subscribe to most events
    socket->SetEventHandler(*this, SOCKET_ID);
    socket->SetNotify(wxSOCKET_CONNECTION_FLAG | wxSOCKET_LOST_FLAG);
//    socket->SetFlags(wxSOCKET_WAITALL);
    socket->Notify(true);

    // connect
    socket->Connect(addr, false);
    // Wait until the request completes or until we decide to give up
    bool waitmore = true;
    unsigned short waitCount = 0;
    while ( !socket->WaitOnConnect(0, 300) && waitmore ) {
        // possibly give some feedback to the user,
        // and update waitmore as needed.
        if(++waitCount > 20) waitmore = false;
    }
    connected = socket->IsConnected();
    
    if (connected) {
        // connect SocketInputStream with TextInputStream for reading input
        socketInputStream = new wxSocketInputStream(*socket);
        textInputStream = new wxTextInputStream(*socketInputStream);
    }
    
    cout << "[FireClient] " << "connection " << (connected?"established":"failed") << endl;
    
    return connected;
}

wxString FireClient::request(wxString query) {
    if (!connected || query.IsEmpty()) return wxString(wxT(""));
    
    query += wxT("\r\n");
    // clear input string before awaiting new input
    if (!input.IsEmpty()) input.Clear();
    // send query to server
    socket->Write(query.mb_str(), query.Length());
    
    if (textInputStream != 0) {
        input = textInputStream->ReadLine();
    }
    
    // wait until new input comes in
    // Wait until the request completes or until we decide to give up
/*    bool waitmore = true;
    unsigned short waitCount = 0;
    while ( !socket->WaitForRead(0, 300) && waitmore ) {
        // possibly give some feedback to the user,
        // and update waitmore as needed.
        if(++waitCount > 20) waitmore = false;
    }
*/  

    /* Wait for read does not return if there IS sth to read!
     * I don't understand this and I can't believe we must use 
     * an extra thread for this!
     * It is also not acceptable to wait one second for every
     * transaction!
     * !!! solve !!!
     */
    //socket->WaitForRead(3);
    
    cout << "[FireClient] " << "query:  " << query.mb_str() << endl;
    cout << "[FireClient] " << "result: " << input.mb_str() << endl;
    
    return input;
}

bool FireClient::release() {
    
    // be kind and say goodbye to the fire server
    socket->Write(wxT("bye\r\n"), 5);
    socket->Destroy();
    connected = false;
    
    return true;
}

void FireClient::OnSocketEvent(wxSocketEvent& event)
{
    // The socket that had the event
    //wxSocketBase* socket = event.GetSocket();



    switch(event.GetSocketEvent()) {
        case wxSOCKET_CONNECTION: {
            connected = true;
            break;
        }
        case wxSOCKET_OUTPUT: {
            // not handled
            break;
        }
        case wxSOCKET_INPUT: {
            // Reads a line from the input stream and returns it
            // (without the end of line character).
            cout << "[FireClient] " << "socket input event" << endl;
            //cout << "socket input: " << input << endl;
            break;
        }
        case wxSOCKET_LOST: {
            socket->Destroy();
            connected = false;
            break;
        }
    }
}

