/*
 *  Copyright (C) 2006 DFKI GmbH
 *  Image Understanding and Pattern Recognition Lab
 *  Author: Christian Kofler <christian.kofler@dfki.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef NETWORKER_H_
#define NETWORKER_H_

#include <wx/wx.h>
#include <wx/socket.h>
#include <wx/sckstrm.h>
#include <wx/txtstrm.h>

#define SOCKET_ID 12345

class FireClient : public wxEvtHandler {
    
public:
	FireClient();
	virtual ~FireClient();
    
    bool connect(wxString host, unsigned short port);
    wxString request(wxString query);
    bool release();

    void OnSocketEvent(wxSocketEvent& event);
    inline bool isConnected() { return connected; }
    
private:
    /** the socket for the connection */
    wxSocketClient* socket;
    /**
     * socketInputStream is redirected to a textInputStream
     * that can be read with Readline()
     */
    wxSocketInputStream* socketInputStream;
    wxTextInputStream* textInputStream;
    /** the received input */
    wxString input;
    /** indicates whether or not a connection to the fire server exists */
    bool connected;

    DECLARE_EVENT_TABLE()
    
};

#endif /*NETWORKER_H_*/
