/* 
 *  Copyright (C) 2006 DFKI GmbH
 *  Image Understanding and Pattern Recognition Lab
 *  Author: Christian Kofler <christian.kofler@dfki.de>
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "FireItem.h"

//BEGIN_EVENT_TABLE(FireItem, wxThumbnailItem)
//    EVT_PAINT(FireItem::OnPaint)
//END_EVENT_TABLE()

IMPLEMENT_CLASS(FireItem, wxThumbnailItem)

FireItem::FireItem(const FireResult& fireResult, float _scale) {
    Init();
    Create(fireResult, _scale);
}

FireItem::FireItem(const FireItem& item) {
    Init();
    Create(item.result, item.scale);
}

void FireItem::operator=(const FireItem& item) {
    Init();
    Create(item.result, item.scale);
}

FireItem::FireItem() {
    Init();
}

FireItem::~FireItem() {
    if (image != 0) delete image;
    if (thumbnail != 0) delete thumbnail;
}

void FireItem::Init() {
    image = 0;
    thumbnail = 0;
    scale = 1.f;
    result.setName(wxT(""));
    result.setScore(0.f);
}

bool FireItem::Create(const FireResult& fireResult, float _scale) {
   
    result = fireResult;
    scale = _scale;

    if (!wxFileExists(getName())) {
        result.setScore(-1.f);
        return false;
    }
        
    // load image -> image
    if(image != 0) delete image;
    image = new wxImage(getName());
    // scale image -> thumbnail
    if (thumbnail != 0) delete thumbnail;
    thumbnail = new wxBitmap(image->Scale((int)(image->GetWidth()*scale), (int)(image->GetHeight()*scale)));
    
    wxThumbnailItem::SetFilename(getName());
    
    return true;
}

wxSize FireItem::DoGetBestSize() const {
    wxSize size;
    size.x = thumbnail->GetWidth();
    size.y = thumbnail->GetHeight();
    
    return size;    
}

bool FireItem::Draw(wxDC& dc, wxThumbnailCtrl* WXUNUSED(ctrl), const wxRect& rect, int WXUNUSED(style)) {
    if (thumbnail->Ok()) {
        int x = rect.x + (rect.width - thumbnail->GetWidth())/2;
        int y = rect.y + (rect.height - thumbnail->GetHeight())/2;

        dc.DrawBitmap(*thumbnail, x, y);
    }
    
    return true;
}

bool FireItem::Load(wxThumbnailCtrl* ctrl, bool forceLoad)
{
    if (thumbnail->Ok() && !forceLoad)
        return true;

    if (!wxFileExists(getName()))
        return false;
    
    // load image -> image
    if(image != 0) delete image;
    image = new wxImage(getName());
    // scale image -> thumbnail
    if (thumbnail != 0) delete thumbnail;
    thumbnail = new wxBitmap(image->Scale((int)(image->GetWidth()*scale), (int)(image->GetHeight()*scale)));
    
    return true;
}

void FireItem::setScale(float value) {
    if (image == 0)
        return;
    scale = value;
    if (thumbnail != 0) delete thumbnail;
    thumbnail = new wxBitmap(image->Scale((int)(image->GetWidth()*scale), (int)(image->GetHeight()*scale)));
}


