/* 
 *  Copyright (C) 2006 DFKI GmbH
 *  Image Understanding and Pattern Recognition Lab
 *  Author: Christian Kofler <christian.kofler@dfki.de>
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef FIREITEM_H_
#define FIREITEM_H_

#include <wx/wx.h>

#include "thumbnailctrl.h"
#include "FireResult.h"

/**
 * FireItem represents a thumbnail of an image in FireWatch.
 * It contains the image itself as well as the score it got (if any).
 * The visual representation lets the user set (+/0/-) for requeries.
 */
class FireItem : public wxThumbnailItem {
    
    DECLARE_CLASS(FireItem)
    
    public:
        /**
         * create a FireItem with
         * @param _filename where to load the image
         * @param _scale the current scale factor
         * @param _score the score of the image in a Fire query
         */
        FireItem(const FireResult& fireResult, float _scale=1.f);
        FireItem(const FireItem& item);
        FireItem();    
        	virtual ~FireItem();
            
        void operator=(const FireItem&);
            
        wxSize DoGetBestSize() const;
        
        virtual bool Draw(wxDC& dc, wxThumbnailCtrl* ctrl, const wxRect& rect, int style) ;
        
        virtual bool Load(wxThumbnailCtrl* ctrl, bool forceLoad) ;

        void Init();

        bool Create(const FireResult& fireResult, float _scale);
    
        /**
         * where the file is located in the file system
         */ 
        inline wxString getName() { return result.getName(); }
        
        /**
         * the current score in a Fire query
         */
        inline float getScore() { return result.getScore(); }

        /**
         * to scale thumbnails on-the fly
         */
        void setScale(float value);
        inline float getScale() { return scale; }
        
        const wxBitmap& getThumbnail() { return *thumbnail; }
        const wxImage& getImage() { return *image; }
    
    private:
        FireResult result;      //< contains Fire information
        wxImage* image;         //< the original image (scale=1.f)
        wxBitmap* thumbnail;    //< the scaled version of the image
        float scale;
        
};

#endif /*FIREITEM_H_*/
