/* 
 *  Copyright (C) 2006 DFKI GmbH
 *  Image Understanding and Pattern Recognition Lab
 *  Author: Christian Kofler <christian.kofler@dfki.de>
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// Generated by DialogBlocks (Personal Edition), Di 31 Jan 2006 14:34:02 CET

#ifndef _SELECTDIALOG_H_
#define _SELECTDIALOG_H_

#if defined(__GNUG__) && !defined(__APPLE__)
#pragma interface "SelectDialog.cc"
#endif

/*!
 * Includes
 */

////@begin includes
////@end includes

#include "FireItem.h"

/*!
 * Forward declarations
 */

////@begin forward declarations
class SelectCanvas;
////@end forward declarations

class SelectDialog;
class RootFrame;

/*!
 * Control identifiers
 */

////@begin control identifiers
#define ID_DIALOG 10007
#define SYMBOL_SELECTDIALOG_STYLE wxCAPTION|wxSYSTEM_MENU|wxCLOSE_BOX
#define SYMBOL_SELECTDIALOG_TITLE _("Select Region")
#define SYMBOL_SELECTDIALOG_IDNAME ID_DIALOG
#define SYMBOL_SELECTDIALOG_SIZE wxDefaultSize
#define SYMBOL_SELECTDIALOG_POSITION wxDefaultPosition
#define ID_SELECTCANVAS 10008
#define ID_SLIDER_SELECTION 10004
#define ID_CLEAR_SELECTION 10010
#define ID_SEND_SELECTION 10013
#define ID_BUTTON3 10015
////@end control identifiers

/*!
 * Compatibility
 */

#ifndef wxCLOSE_BOX
#define wxCLOSE_BOX 0x1000
#endif
#ifndef wxFIXED_MINSIZE
#define wxFIXED_MINSIZE 0
#endif


class SelectCanvas: public wxScrolledWindow {
    DECLARE_EVENT_TABLE()
public:
    SelectCanvas(wxWindow *parent, wxWindowID id, const wxPoint& pos, const wxSize& size, const long style);

    virtual void OnPaint(wxPaintEvent&);

    /// Processes mouse events
    void OnMouse(wxMouseEvent& event);
    
    void updateZoom(float scale);
    
    void setFireItem(const FireItem& item);
    
    void clearSelection();
    
    inline bool hasSelection() { return selected; }
    
    wxString getSelectedImageName();
    
    
private:
    SelectDialog* parent;
    bool selecting;
    bool selected;
    wxPoint startPoint;
    wxPoint currentPoint;
    wxPoint endPoint;
    
    FireItem fireItem;
    
};


/*!
 * SelectDialog class declaration
 */

class SelectDialog: public wxDialog
{    
    DECLARE_DYNAMIC_CLASS( SelectDialog )
    DECLARE_EVENT_TABLE()

public:
    /// Constructors
    SelectDialog( );
    SelectDialog( wxWindow* parent, wxWindowID id = SYMBOL_SELECTDIALOG_IDNAME, const wxString& caption = SYMBOL_SELECTDIALOG_TITLE, const wxPoint& pos = SYMBOL_SELECTDIALOG_POSITION, const wxSize& size = SYMBOL_SELECTDIALOG_SIZE, long style = SYMBOL_SELECTDIALOG_STYLE );

    /// Creation
    bool Create( wxWindow* parent, wxWindowID id = SYMBOL_SELECTDIALOG_IDNAME, const wxString& caption = SYMBOL_SELECTDIALOG_TITLE, const wxPoint& pos = SYMBOL_SELECTDIALOG_POSITION, const wxSize& size = SYMBOL_SELECTDIALOG_SIZE, long style = SYMBOL_SELECTDIALOG_STYLE );

    /// Creates the controls and sizers
    void CreateControls();

////@begin SelectDialog event handler declarations

    /// wxEVT_CLOSE_WINDOW event handler for ID_DIALOG
    void OnCloseWindow( wxCloseEvent& event );

    /// wxEVT_IDLE event handler for ID_DIALOG
    void OnIdle( wxIdleEvent& event );

    /// All mouse events event handler for ID_SELECTCANVAS
    void OnMouse( wxMouseEvent& event );

    /// wxEVT_COMMAND_SLIDER_UPDATED event handler for ID_SLIDER_SELECTION
    void OnZoom( wxCommandEvent& event );

    /// wxEVT_COMMAND_BUTTON_CLICKED event handler for ID_CLEAR_SELECTION
    void OnClearSelection( wxCommandEvent& event );

    /// wxEVT_COMMAND_BUTTON_CLICKED event handler for ID_SEND_SELECTION
    void OnSendSelection( wxCommandEvent& event );

    /// wxEVT_COMMAND_BUTTON_CLICKED event handler for ID_BUTTON3
    void OnExit( wxCommandEvent& event );

////@end SelectDialog event handler declarations

////@begin SelectDialog member function declarations

    /// Retrieves bitmap resources
    wxBitmap GetBitmapResource( const wxString& name );

    /// Retrieves icon resources
    wxIcon GetIconResource( const wxString& name );
////@end SelectDialog member function declarations

    /// Should we show tooltips?
    static bool ShowToolTips();

////@begin SelectDialog member variables
    SelectCanvas* selectCanvas;
    wxSlider* zoomSlider;
////@end SelectDialog member variables

    void setFireItem(const FireItem& item) { 
        if (selectCanvas != 0) selectCanvas->setFireItem(item);
        zoomSlider->SetValue(100);
    }
    
    RootFrame* rootFrame;
    
};



#endif
    // _SELECTDIALOG_H_
